@@ -78,7 +78,8 @@ GEdit <- setRefClass("GEdit",
 
                                 handler_id <<- add_handler_changed(handler, action)
                                 ## change on blur or return
-                                add_handler_blur(function(h,...) invoke_change_handler())
+                                ## add_handler_blur(function(h,...) invoke_change_handler())
+                                ## change only on return. Use blur to add other
                                 add_handler_keystroke(function(h,...) if(h$key == "Return") invoke_change_handler())
 
                                 callSuper(toolkit)
